@@ -779,7 +779,7 @@ class Sf:
 
         account_page_layouts_bulk = account_page_layouts_bulk.merge(object_dataframe, left_on='ProfileLayout.TableEnumOrId', right_on='ObjectID', how='left').copy()
         account_page_layouts_bulk['DeveloperName'] = account_page_layouts_bulk.apply(lambda row: row['DeveloperName'] if pd.notnull(row['DeveloperName']) else row['ProfileLayout.TableEnumOrId'], axis=1)
-        account_page_layouts_bulk.drop(['ObjectID','attributes'], axis=1, inplace=True)
+        account_page_layouts_bulk.drop(['attributes'], axis=1, inplace=True)
         
         # Fill in the RecordTypeName colum with the Master Record Type Name
         account_page_layouts_bulk['RecordTypeName'] = account_page_layouts_bulk['RecordTypeName'].apply(lambda row: row if row else 'Master')
@@ -791,7 +791,7 @@ class Sf:
         else:
             sf_meta_instance = ".".join(self.instance.split(".")[:1])
         
-        account_page_layouts_bulk['Edit Link'] = account_page_layouts_bulk.apply(lambda row: "https://" + sf_meta_instance + ".lightning.force.com/lightning/setup/ObjectManager/" + row['DeveloperName'] + "/PageLayouts/" + row['ProfileLayout.LayoutId'] + "/view", axis=1)
+        account_page_layouts_bulk['Edit Link'] = account_page_layouts_bulk.apply(lambda row: "https://" + sf_meta_instance + ".lightning.force.com/lightning/setup/ObjectManager/" + (row['DeveloperName'] if str(row['ObjectID']) == 'nan' else row['ObjectID']) + "/PageLayouts/" + row['ProfileLayout.LayoutId'] + "/view", axis=1)
         
         if return_pivot_table:
             return account_page_layouts_bulk.pivot(index='ProfileName', columns=['DeveloperName','RecordTypeName'], values='PageLayout')
@@ -917,11 +917,11 @@ class Sf:
         parsed_layout_metadata['customButtonsList'] = layout_metadata['customButtons'][0]
         parsed_layout_metadata['excludeButtonsList'] = layout_metadata['excludeButtons'][0]
         # Adding required fields from the main page layout gives you the final list of mini layout items
-        parsed_layout_metadata['miniLayoutDict'] = dict(layout_metadata['miniLayout'][0])
-        parsed_layout_metadata['layoutSectionsDataFrame'] = parse_layoutSections(layout_metadata['layoutSections'][0])
-        parsed_layout_metadata['platformActionListDataFrame'] = parse_platformActionList(layout_metadata['platformActionList'][0])
-        parsed_layout_metadata['quickActionListDataFrame'] = parse_quickActionList(layout_metadata['quickActionList'][0])
-        parsed_layout_metadata['relatedListDataFrame'] = pd.DataFrame(layout_metadata['relatedLists'][0])
+        parsed_layout_metadata['miniLayoutDict'] = dict(layout_metadata['miniLayout'][0]) if layout_metadata['miniLayout'][0] != None else {'fields': [],'relatedLists': []}
+        parsed_layout_metadata['layoutSectionsDataFrame'] = parse_layoutSections(layout_metadata['layoutSections'][0]) if layout_metadata['layoutSections'][0] != None else pd.DataFrame()
+        parsed_layout_metadata['platformActionListDataFrame'] = parse_platformActionList(layout_metadata['platformActionList'][0]) if layout_metadata['platformActionList'][0] != None else pd.DataFrame()
+        parsed_layout_metadata['quickActionListDataFrame'] = parse_quickActionList(layout_metadata['quickActionList'][0]) if layout_metadata['quickActionList'][0] != None else pd.DataFrame()
+        parsed_layout_metadata['relatedListDataFrame'] = pd.DataFrame(layout_metadata['relatedLists'][0]) if layout_metadata['relatedLists'][0] != None else pd.DataFrame()
         return parsed_layout_metadata
     
     ### ----------------------------------------------------------------------------------------------------
